@@ -1,10 +1,10 @@
 ##' Calculate Wald og Likelihood based (profile likelihood) confidence intervals
-##' 
+##'
 ##' Calculates either Wald confidence limits: \deqn{\hat{\theta} \pm
 ##' z_{\alpha/2}*\hat\sigma_{\hat\theta}} or profile likelihood confidence
 ##' limits, defined as the set of value \eqn{\tau}:
 ##' \deqn{logLik(\hat\theta_{\tau},\tau)-logLik(\hat\theta)< q_{\alpha}/2}
-##' 
+##'
 ##' where \eqn{q_{\alpha}} is the \eqn{\alpha} fractile of the \eqn{\chi^2_1}
 ##' distribution, and \eqn{\hat\theta_{\tau}} are obtained by maximizing the
 ##' log-likelihood with tau being fixed.
@@ -28,7 +28,7 @@
 ##' @seealso \code{\link{bootstrap}{lvm}}
 ##' @keywords models regression
 ##' @examples
-##' 
+##'
 ##' m <- lvm(y~x)
 ##' d <- sim(m,100)
 ##' e <- estimate(y~x, d)
@@ -46,7 +46,7 @@ confint.lvmfit <- function(object,parm=seq_len(length(coef(object))),level=0.95,
   if (is.character(parm)) {
     parm <- parpos(Model(object),p=parm)
     parm <- parm[attributes(parm)$ord]
-  } 
+  }
   if (!profile) {
     return(confint.default(object,parm=parm,level=level,...))
   }
@@ -54,21 +54,20 @@ confint.lvmfit <- function(object,parm=seq_len(length(coef(object))),level=0.95,
   for (i in parm) {
     res <- rbind(res, profci.lvmfit(object,parm=i,level=level,profile=profile,n=n,curve=curve,interval=interval,lower=lower,upper=upper,...))
     if (curve) return(res)
-  }  
+  }
   rownames(res) <- names(coef(object))[parm]
   colnames(res) <- paste((c(0,1) + c(1,-1)*(1-level)/2)*100,"%")
-  return(res) 
+  return(res)
 }
 
 
 ##' @export
-confint.multigroupfit <- function(object,parm=1:length(pars(object)),level=0.95,
+confint.multigroupfit <- function(object,parm=seq_along(pars(object)),level=0.95,
                                   estimates=TRUE,...) {
   p <- 1-(1-level)/2
   res <- cbind(pars(object),pars(object)) + qnorm(p)*cbind(-1,1)%x%diag(vcov(object))^0.5
-  colnames(res) <- paste(c(1-p,p)*100,"%",sep="")
+  colnames(res) <- paste0(c(1-p,p)*100,"%")
   rownames(res) <- parpos(object); rownames(res)[is.na(rownames(res))] <- ""
   if (estimates) res <- cbind(coef(object,level=0)[,c(1,2,4)],res)
   res[parm,,drop=FALSE]
 }
-  
