@@ -1,8 +1,8 @@
 ##' Identify candidates of equivalent models
-##' 
+##'
 ##' Identifies candidates of equivalent models
-##' 
-##' 
+##'
+##'
 ##' @param x \code{lvmfit}-object
 ##' @param rel Formula or character-vector specifying two variables to omit from
 ##' the model and subsequently search for possible equivalent models
@@ -20,21 +20,21 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
   if (missing(rel)) stop("Specify association 'rel' (formula or character vector)")
   if (class(rel)[1]=="formula") {
     myvars <- all.vars(rel)
-  } else {    
+  } else {
     myvars <- rel
   }
   if (length(myvars)!=2) stop("Two variables only")
   x0 <- Model(x)
-  cancel(x0) <- rel  
+  cancel(x0) <- rel
   e0 <- estimate(x0,data=model.frame(x),weight=Weight(x),estimator=x$estimator,...)
   if (k!=1) {
     p0 <- coef(x)
     p0[] <- 0
     p0[match(names(coef(e0)),names(p0))] <- coef(e0)
-    S0 <- score(x,p=p0)[,,drop=TRUE]; 
-    I0 <- information(x,p=p0)   
+    S0 <- score(x,p=p0)[,,drop=TRUE];
+    I0 <- information(x,p=p0)
     T0 <- rbind(S0)%*%solve(I0)%*%cbind(S0); names(T0) <- "Q"
-  } 
+  }
   s <- modelsearch(e0,k=k)
   relname <- c(paste(myvars,collapse=lava.options()$symbol[2]),
                paste(rev(myvars),collapse=lava.options()$symbol[2]))
@@ -44,18 +44,18 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
     T0 <- s$test[relidx,1]
   }
 ##  else {
-##    if (covariance(Model(x))$rel[myvars[1],myvars[2]]==0) {    
+##    if (covariance(Model(x))$rel[myvars[1],myvars[2]]==0) {
     ## paridx <- which(names(coef(x))%in%relname)
     ## if (length(paridx)==0) {
     ##   paridx <- which(names(coef(x))%in%paste(myvars,collapse=lava.options()$symbol[1]))
-    ## }    
+    ## }
 ##    p0 <- coef(x)
 ##    p0[paridx] <- 0
   ##   p0[] <- 0
   ##   p0[match(names(coef(e0)),names(p0))] <- coef(e0)
   ##   S0 <- score(x,p=p0)[,,drop=TRUE]
-  ##   I0 <- information(x,p=p0,data=NULL,n=nrow(model.frame(x)))   
-  ##   T0 <- rbind(S0)%*%solve(I0)%*%cbind(S0)    
+  ##   I0 <- information(x,p=p0,data=NULL,n=nrow(model.frame(x)))
+  ##   T0 <- rbind(S0)%*%solve(I0)%*%cbind(S0)
   ## }
   T <- s$test[,1]
   Equiv <- setdiff(which(abs(T-T0)<tol),relidx)
@@ -63,7 +63,7 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
   if (omitrel) { ## Don't save models including 'rel'
     keep <- c()
     if (length(Equiv)>0) {
-      for (i in 1:length(Equiv)) {
+      for (i in seq_len(length(Equiv))) {
         newvars <- s$var[[Equiv[i]]]
         if (!any(apply(newvars,1,function(z) all(z%in%myvars)))) keep <- c(keep,Equiv[i])
       }
@@ -71,7 +71,7 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
     }
     keep <- c()
     if (length(Improve)>0) {
-      for (i in 1:length(Improve)) {
+      for (i in seq_len(length(Improve))) {
         newvars <- s$var[[Improve[i]]]
         if (!any(apply(newvars,1,function(z) all(z%in%myvars)))) keep <- c(keep,Improve[i])
       }
@@ -81,10 +81,10 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
   eqvar <- ivar <- NULL
   models <- list()
   if (length(Equiv)>0){
-    for (i in 1:length(Equiv)) {      
+    for (i in seq_len(length(Equiv))) {
       xnew <- x0
       newvars <- s$var[[Equiv[i]]]
-      for (j in 1:nrow(newvars)) {
+      for (j in seq_len(nrow(newvars))) {
         exo.idx <- which(newvars[j,]%in%index(x0)$exogenous)
         if (length(exo.idx)>0) {
           xnew <- regression(xnew,from=newvars[j,exo.idx],to=newvars[j,setdiff(1:2,exo.idx)])
@@ -97,10 +97,10 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
     eqvar <- s$var[Equiv]
   }
   if (length(Improve)>0)   {
-      for (i in 1:length(Improve)) {
+      for (i in seq_len(length(Improve))) {
       xnew <- x0
       newvars <- s$var[[Improve[i]]]
-      for (j in 1:nrow(newvars)) {
+      for (j in seq_len(nrow(newvars))) {
         exo.idx <- which(newvars[j,]%in%index(x0)$exogenous)
         if (length(exo.idx)>0) {
           xnew <- regression(xnew,from=newvars[j,exo.idx],to=newvars[j,setdiff(1:2,exo.idx)])
@@ -111,7 +111,7 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
       models <- c(models,list(xnew))
     }
     ivar <- s$var[Improve]
-  }  
+  }
   res <- list(equiv=eqvar, improve=ivar, scoretest=s, models=models, I=Improve, E=Equiv, T0=T0, vars=myvars)
   class(res) <- "equivalence"
   return(res)
@@ -119,12 +119,12 @@ equivalence <- function(x,rel,tol=1e-3,k=1,omitrel=TRUE,...) {
 
 ##' @export
 print.equivalence <- function(x,...) {
-  cat("  0)\t ",paste(x$vars,collapse=lava.options()$symbol[2]),"  (",formatC(x$T0),")\n",sep="")
+  cat("  0)\t ",paste0(x$vars,collapse=lava.options()$symbol[2]),"  (",formatC(x$T0),")\n")
   cat("Empirical equivalent models:\n")
   if (length(x$E)==0)
     cat("\t none\n")
   else
-    for (i in 1:length(x$E)) {        
+    for (i in seq_len(length(x$E))) {
       cat("  ",i,")\t ",  x$scoretest$res[x$E[i],"Index"],
           "  (",x$scoretest$res[x$E[i],1],")",
           "\n",sep="")
@@ -133,7 +133,7 @@ print.equivalence <- function(x,...) {
   if (length(x$I)==0)
     cat("\t none\n")
   else
-  for (i in 1:length(x$I)) {
+  for (i in seq_len(length(x$I))) {
       cat("  ",i,")\t ",  x$scoretest$res[x$I[i],"Index"],
           "  (",x$scoretest$res[x$I[i],1],")",
           "\n",sep="")
