@@ -8,15 +8,16 @@ estimate.list <- function(x,...) {
 }
 
 
-##' Estimation of functional of parameters 
+##' Estimation of functional of parameters
 ##'
 ##' Estimation of functional of parameters.
 ##' Wald tests, robust standard errors, cluster robust standard errors,
 ##' LRT (when \code{f} is not a function)...
 ##' @param x model object (\code{glm}, \code{lvmfit}, ...)
 ##' @param f transformation of model parameters and (optionally) data, or contrast matrix (or vector)
+##' @param ... additional arguments to lower level functions
 ##' @param data \code{data.frame}
-##' @param id (optional) id-variable corresponding to iid decomposition of model parameters. 
+##' @param id (optional) id-variable corresponding to iid decomposition of model parameters.
 ##' @param iddata (optional) id-variable for 'data'
 ##' @param stack If TRUE (default)  the i.i.d. decomposition is automatically stacked according to 'id'
 ##' @param average If TRUE averages are calculated
@@ -27,45 +28,52 @@ estimate.list <- function(x,...) {
 ##' @param type Type of small-sample correction
 ##' @param keep (optional) Index of parameters to keep
 ##' @param contrast (optional) Contrast matrix for final Wald test
-##' @param null (optional) Null hypothesis to test 
+##' @param null (optional) Null hypothesis to test
 ##' @param vcov (optional) covariance matrix of parameter estimates (e.g. Wald-test)
 ##' @param coef (optional) parameter coefficient
+##' @param robust If TRUE robust standard errors are calculated. If
+##' FALSE p-values for linear models are calculated from t-distribution
+##' @param df Degrees of freedom (default obtained from 'df.residual')
 ##' @param print (optional) print function
 ##' @param labels (optional) names of coefficients
-##' @param ... additional arguments to lower level functions
 ##' @export
 ##' @examples
-##' 
+##'
 ##' ## Simulation from logistic regression model
 ##' m <- lvm(y~x+z);
 ##' distribution(m,y~x) <- binomial.lvm("logit")
 ##' d <- sim(m,1000)
 ##' g <- glm(y~z+x,data=d,family=binomial())
 ##' g0 <- glm(y~1,data=d,family=binomial())
-##' 
+##'
 ##' ## LRT
 ##' estimate(g,g0)
-##' 
+##'
 ##' ## Plain estimates (robust standard errors)
 ##' estimate(g)
-##' 
+##'
 ##' ## Testing contrasts
 ##' estimate(g,null=0)
 ##' estimate(g,rbind(c(1,1,0),c(1,0,2)))
 ##' estimate(g,rbind(c(1,1,0),c(1,0,2)),null=c(1,2))
 ##' estimate(g,2:3) ## same as rbind(c(0,1,0),c(0,0,1))
-##' 
+##' ## Alternative syntax
+##' estimate(g,"z","z"-"x",2*"z"-3*"x")
+##' estimate(g,"1","2"-"3",null=c(0,1))
+##' ## Usual (non-robust) confidence intervals
+##' estimate(g,robust=FALSE)
+##'
 ##' ## Transformations
 ##' estimate(g,function(p) p[1]+p[2])
-##' 
+##'
 ##' ## Multiple parameters
 ##' e <- estimate(g,function(p) c(p[1]+p[2],p[1]*p[2]))
 ##' e
 ##' vcov(e)
-##' 
+##'
 ##' ## Label new parameters
 ##' estimate(g,function(p) list("a1"=p[1]+p[2],"b1"=p[1]*p[2]))
-##'
+##' ##'
 ##' ## Multiple group
 ##' m <- lvm(y~x)
 ##' m <- baptize(m)
@@ -74,7 +82,7 @@ estimate.list <- function(x,...) {
 ##' estimate(e) ## Wrong
 ##' estimate(e,id=rep(seq(nrow(d1)),2))
 ##' estimate(lm(y~x,d1))
-##' 
+##'
 ##' ## Marginalize
 ##' f <- function(p,data)
 ##'   list(p0=lava:::expit(p[1] + p[3]*data[,"z"]),
@@ -83,54 +91,66 @@ estimate.list <- function(x,...) {
 ##' e
 ##' estimate(e,diff)
 ##' estimate(e,cbind(1,1))
-##' 
+##'
 ##' ## Clusters and subset (conditional marginal effects)
 ##' d$id <- rep(seq(nrow(d)/4),each=4)
 ##' estimate(g,function(p,data)
 ##'          list(p0=lava:::expit(p[1] + p["z"]*data[,"z"])),
 ##'          subset=d$z>0, id=d$id, average=TRUE)
-##' 
+##'
 ##' ## More examples with clusters:
 ##' m <- lvm(c(y1,y2,y3)~u+x)
 ##' d <- sim(m,10)
 ##' l1 <- glm(y1~x,data=d)
 ##' l2 <- glm(y2~x,data=d)
 ##' l3 <- glm(y3~x,data=d)
-##' 
+##'
 ##' ## Some random id-numbers
 ##' id1 <- c(1,1,4,1,3,1,2,3,4,5)
 ##' id2 <- c(1,2,3,4,5,6,7,8,1,1)
 ##' id3 <- seq(10)
-##' 
+##'
 ##' ## Un-stacked and stacked i.i.d. decomposition
 ##' iid(estimate(l1,id=id1,stack=FALSE))
 ##' iid(estimate(l1,id=id1))
-##' 
+##'
 ##' ## Combined i.i.d. decomposition
 ##' e1 <- estimate(l1,id=id1)
 ##' e2 <- estimate(l2,id=id2)
 ##' e3 <- estimate(l3,id=id3)
 ##' (a2 <- merge(e1,e2,e3))
-##' 
+##'
 ##' ## Same:
 ##' iid(a1 <- merge(l1,l2,l3,id=list(id1,id2,id3)))
-##' 
+##'
 ##' iid(merge(l1,l2,l3,id=TRUE)) # one-to-one (same clusters)
 ##' iid(merge(l1,l2,l3,id=FALSE)) # independence
-##' @aliases estimate.default estimate.estimate merge.estimate stack.estimate
+##' @aliases estimate.default estimate.estimate merge.estimate
 ##' @method estimate default
 ##' @export
-estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FALSE,subset,
+estimate.default <- function(x=NULL,f=NULL,...,data,id,iddata,stack=TRUE,average=FALSE,subset,
                              score.deriv,level=0.95,iid=TRUE,
                              type=c("robust","df","mbn"),
                              keep,
-                             contrast,null,vcov,coef,print=NULL,labels,...) {
+                             contrast,null,vcov,coef,
+                             robust=TRUE,df=NULL,
+                             print=NULL,labels) {
+    expr <- suppressWarnings(inherits(try(f,silent=TRUE),"try-error"))
+    if (!missing(coef)) {
+        pp <- coef
+    } else {
+        pp <- suppressWarnings(try(stats::coef(x),"try-error"))
+    }
+    if (expr || is.character(f)) { ## || is.call(f)) {
+        ## if (is.call(f)) f <- parsedesign(seq(length(pp)),f,...)
+        f <- parsedesign(names(pp),substitute(f),...)
+    }
     if (!is.null(f) && !is.function(f)) {
         if (!(is.matrix(f) | is.vector(f))) return(compare(x,f,...))
         contrast <- f; f <- NULL
     }
     if (missing(data)) data <- tryCatch(model.frame(x),error=function(...) NULL)
-    
+
     ##if (is.matrix(x) || is.vector(x)) contrast <- x
     alpha <- 1-level
     alpha.str <- paste(c(alpha/2,1-alpha/2)*100,"",sep="%")
@@ -150,6 +170,7 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
         if (is.logical(vcov)) vcov <- vcov(x)
         iidtheta <- NULL
     }
+
     if (!missing(subset)) {
         e <- substitute(subset)
         expr <- suppressWarnings(inherits(try(subset,silent=TRUE),"try-error"))
@@ -157,7 +178,7 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
         ##subset <- eval(e, data, parent.frame())
         if (is.character(subset)) subset <- data[,subset]
         if (is.numeric(subset)) subset <- subset>0
-    }    
+    }
     idstack <- NULL
     if (!missing(id)) {
         if (is.null(iidtheta)) stop("'iid' method needed")
@@ -179,14 +200,15 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
         if (stack) {
             N <- nrow(iidtheta)
             clidx <- NULL
+            atr <- attributes(iidtheta)
+            atr$dimnames <- NULL
+            atr$dim <- NULL
             if (!lava.options()$cluster.index) {
                 iidtheta <- matrix(unlist(by(iidtheta,id,colSums)),byrow=TRUE,ncol=ncol(iidtheta))
+                attributes(iidtheta)[names(atr)] <- atr
                 idstack <- sort(unique(id))
-            } else { 
+            } else {
                 clidx <- mets::cluster.index(id,mat=iidtheta,return.all=TRUE)
-                atr <- attributes(iidtheta)
-                atr$dimnames <- NULL
-                atr$dim <- NULL
                 iidtheta <- clidx$X
                 attributes(iidtheta)[names(atr)] <- atr
                 idstack <- id[as.vector(clidx$firstclustid)+1]
@@ -194,19 +216,22 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
             if (is.null(attributes(iidtheta)$N)) {
                 attributes(iidtheta)$N <- N
             }
-        } else idstack <- id        
+        } else idstack <- id
     } else {
         if (!is.null(data)) idstack <- rownames(data)
     }
     if (!is.null(iidtheta)) rownames(iidtheta) <- idstack
-
+    if (!robust) {
+        if (inherits(x,"lm") && family(x)$family=="gaussian" && is.null(df)) df <- x$df.residual
+        if (missing(vcov)) vcov <- stats::vcov(x)
+    }
     if (!is.null(iidtheta) && missing(vcov)) {
         ## if (is.null(f))
         V <- crossprod(iidtheta)
         ### Small-sample corrections for clustered data
         K <- NROW(iidtheta)
         N <- attributes(iidtheta)$N
-        if (is.null(N)) N <- K                    
+        if (is.null(N)) N <- K
         p <- NCOL(iidtheta)
         adj1 <- K/(K-p) ## Mancl & DeRouen, 2001
         adj2 <- (N-1)/(N-p)*(K/(K-1)) ## Morel,Bokossa & Neerchal, 2003
@@ -232,11 +257,6 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
             V <- stats::vcov(x)
         }
     }
-    if (!missing(coef)) {
-        pp <- coef
-    } else {
-        pp <- stats::coef(x)
-    }
 
     if (!is.null(f)) {
         form <- names(formals(f))
@@ -250,9 +270,9 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
         }
         if (!is.null(iidtheta)) {
             arglist <- c(list(object=x,data=data,p=pp),list(...))
-            names(arglist)[3] <- parname      
+            names(arglist)[3] <- parname
         } else {
-            arglist <- c(list(object=x,p=pp),list(...))            
+            arglist <- c(list(object=x,p=pp),list(...))
             names(arglist)[2] <- parname
         }
         if (!dots) {
@@ -283,7 +303,7 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
                 else arglist[[parname]] <- p
                 if (is.null(newf))
                     return(do.call("f",arglist))
-                return(do.call("newf",arglist)) }, pp)      
+                return(do.call("newf",arglist)) }, pp)
         }
         if (is.null(iidtheta)) {
             pp <- as.vector(val)
@@ -307,7 +327,7 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
                         D0[i,] <- colMeans(D1)
                     }
                     D <- D0
-                    iid2 <- iidtheta%*%t(D)        
+                    iid2 <- iidtheta%*%t(D)
                 } else { ## Single parameter
                     if (!missing(subset)) { ## Conditional estimate
                         val <- val*subset
@@ -317,9 +337,9 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
                     iid2 <- iidtheta%*%D
                 }
                 pp <- as.vector(colMeans(cbind(val)))
-                iid1 <- (cbind(val)-rbind(pp)%x%cbind(rep(1,N)))/N 
+                iid1 <- (cbind(val)-rbind(pp)%x%cbind(rep(1,N)))/N
                 if (!missing(id)) {
-                    if (!lava.options()$cluster.index) 
+                    if (!lava.options()$cluster.index)
                         iid1 <- matrix(unlist(by(iid1,id,colSums)),byrow=TRUE,ncol=ncol(iid1))
                     else {
                         iid1 <- mets::cluster.index(id,mat=iid1,return.all=FALSE)
@@ -332,7 +352,7 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
                         if (!lava.options()$cluster.index)
                             iid3 <- matrix(unlist(by(iid3,id,colSums)),byrow=TRUE,ncol=ncol(iid3))
                         else
-                            iid3 <- mets::cluster.index(id,mat=iid3,return.all=FALSE)         
+                            iid3 <- mets::cluster.index(id,mat=iid3,return.all=FALSE)
                     }
                     iidtheta <- (iid1+iid2)/phat + rbind(pp)%x%iid3
                     pp <- pp/phat
@@ -351,23 +371,30 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
     }
 
     if (length(pp)==1) res <- rbind(c(pp,diag(V)^0.5)) else res <- cbind(pp,diag(V)^0.5)
-    if (is.null(f) || missing(null))
-        res <- cbind(res,res[,1]-qnorm(1-alpha/2)*res[,2],res[,1]+qnorm(1-alpha/2)*res[,2],(pnorm(abs(res[,1]/res[,2]),lower.tail=FALSE)*2))
-    else 
-        res <- cbind(res,res[,1]-qnorm(1-alpha/2)*res[,2],res[,1]+qnorm(1-alpha/2)*res[,2],(pnorm(abs(res[,1]-null)/res[,2],lower.tail=FALSE))*2)
+    beta0 <- res[,1]
+
+    if (!missing(null) && missing(contrast)) beta0 <- beta0-null
+    if (!is.null(df)) {
+        za <- qt(1-alpha/2,df=df)
+        pval <- 2*pt(abs(res[,1]/res[,2]),df=df,lower.tail=FALSE)
+    } else {
+        za <- qnorm(1-alpha/2)
+        pval <- 2*pnorm(abs(res[,1]/res[,2]),lower.tail=FALSE)
+    }
+    res <- cbind(res,res[,1]-za*res[,2],res[,1]+za*res[,2],pval)
     colnames(res) <- c("Estimate","Std.Err",alpha.str,"P-value")
     if (!is.null(nn)) {
         rownames(res) <- nn
     } else {
         nn <- attributes(res)$varnames
         if (!is.null(nn)) rownames(res) <- nn
-        if (is.null(rownames(res))) rownames(res) <- paste("p",seq(nrow(res)),sep="")
+        if (is.null(rownames(res))) rownames(res) <- paste0("p",seq(nrow(res)))
     }
     coefs <- res[,1,drop=TRUE]; names(coefs) <- rownames(res)
     res <- structure(list(coef=coefs,coefmat=res,vcov=V, iid=NULL, print=print, id=idstack),class="estimate")
     if (iid) res$iid <- iidtheta
-    if (is.null(f) && (!missing(contrast) | !missing(null))) {
-        p <- length(res$coef)    
+    if (!missing(contrast) | !missing(null)) {
+        p <- length(res$coef)
         if (missing(contrast)) contrast <- diag(p)
         if (missing(null)) null <- 0
         if (is.vector(contrast)) {
@@ -377,14 +404,20 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
                 contrast <- diag(nrow=p)[cont,,drop=FALSE]
             }
         }
-        cc <- compare(res,contrast=contrast,null=null,vcov=V,level=level)
+        cc <- compare(res,contrast=contrast,null=null,vcov=V,level=level,df=df)
         res <- structure(c(res, list(compare=cc)),class="estimate")
-        res$coefmat <- with(cc, cbind(estimate,
-                                      (pnorm(abs(estimate[,1]-null)/estimate[,2],lower.tail=FALSE)*2)));
+        if (!is.null(df)) {
+            pval <- with(cc,pt(abs(estimate[,1]-null)/estimate[,2],df=df,lower.tail=FALSE)*2)
+        } else {
+            pval <- with(cc,pnorm(abs(estimate[,1]-null)/estimate[,2],lower.tail=FALSE)*2)
+        }
+        res$coefmat <- with(cc, cbind(estimate,pval))
         colnames(res$coefmat)[5] <- "P-value"
         rownames(res$coefmat) <- cc$cnames
-        res$iid <- res$iid%*%t(contrast)
-        colnames(res$iid) <- cc$cnames
+        if (!is.null(res$iid)) {
+            res$iid <- res$iid%*%t(contrast)
+            colnames(res$iid) <- cc$cnames
+        }
         res$compare$estimate <- NULL
         res$coef <- res$compare$coef
         res$vcov <- res$compare$vcov
@@ -392,20 +425,20 @@ estimate.default <- function(x=NULL,f=NULL,data,id,iddata,stack=TRUE,average=FAL
     if (!missing(keep) && !is.null(keep)) {
         res$coef <- res$coef[keep]
         res$coefmat <- res$coefmat[keep,,drop=FALSE]
-        res$iid <- res$iid[,keep,drop=FALSE]
+        if (!is.null(res$iid)) res$iid <- res$iid[,keep,drop=FALSE]
         res$vcov <- res$vcov[keep,keep,drop=FALSE]
     }
     if (!missing(labels)) {
         names(res$coef) <- labels
-        colnames(res$iid) <- labels
+        if (!is.null(res$iid)) colnames(res$iid) <- labels
         colnames(res$vcov) <- rownames(res$vcov) <- labels
         rownames(res$coefmat) <- labels
     }
-    return(res)  
+    return(res)
 }
 
 
-estimate.glm <- function(x,...) {  
+estimate.glm <- function(x,...) {
     estimate.default(x,...)
 }
 
@@ -419,11 +452,22 @@ print.estimate <- function(x,digits=3,width=25,...) {
     rownames(cc) <- make.unique(unlist(lapply(rownames(cc),
                                                function(x) toString(x,width=width))))
     print(cc,digits=digits,...)
-    if (!is.null(x$compare)) print(x$compare)    
+    if (!is.null(x$compare)) {
+        cat("\n",x$compare$method[3],"\n")
+        cat(paste(" ",x$compare$method[-(1:3)],collapse="\n"),"\n")
+        if (length(x$compare$method)>4) {
+            out <- character()
+            out <- with(x$compare, c(out, paste(names(statistic), "=", format(round(statistic, 4)))))
+            out <- with(x$compare, c(out, paste(names(parameter), "=", format(round(parameter,3)))))
+            fp  <- with(x$compare, format.pval(p.value, digits = digits))
+            out <- c(out, paste("p-value", if (substr(fp, 1L, 1L) == "<") fp else paste("=", fp)))
+            cat(" ",strwrap(paste(out, collapse = ", ")), sep = "\n")
+        }
+    }
 }
 
 ##' @export
-vcov.estimate <- function(object,...) {    
+vcov.estimate <- function(object,...) {
     res <- object$vcov
     nn <- names(coef(object))
     dimnames(res) <- list(nn,nn)
@@ -443,6 +487,7 @@ summary.estimate <- function(object,...) {
 
 ##' @export
 iid.estimate <- function(x,...) {
+    if (is.null(x$iid)) return(NULL)
     dimn <- dimnames(x$iid)
     if (!is.null(dimn)) {
         dimn[[2]] <- names(coef(x))
@@ -456,25 +501,3 @@ iid.estimate <- function(x,...) {
 model.frame.estimate <- function(formula,...) {
     NULL
 }
-
-##' @export
-stack.estimate <- function(x,y,Ix,iIy,weight,dweight,...) {    
-    iid1 <- iid(x)
-    iid2 <- iid(y)
-    if (missing(iIy)) {
-        iIy <- attributes(iid2)$bread
-    }
-    if (!missing(dweight)) {
-        u2 <- apply(solve(iIy)%*%t(iid2),1,function(x) x/weight)
-        Ix <- colSums(
-            rbind(rep(1,ncol(dweight)))%x%u2*
-            rbind(rep(1,ncol(u2)))%x%dweight
-            )
-        Ix <- matrix(Ix,byrow=TRUE,ncol=ncol(iid1))
-    }
-    ii <- iid(merge(x,y))
-    iid1. <- ii[,seq_along(coef(x)),drop=FALSE]
-    iid2. <- ii[,length(coef(x))+seq_along(coef(y)),drop=FALSE] 
-    iid3 <- t(iIy%*%(Ix%*%t(iid1.)))
-    estimate(coef=c(coef(x),coef(y)),iid=cbind(iid1.,iid2.-iid3))
-}
