@@ -1,6 +1,6 @@
 ##' Generic method for removing elements of object
 ##'
-##' @title Remove variables from (model) object. 
+##' @title Remove variables from (model) object.
 ##' @aliases kill kill<- rmvar rmvar<-
 ##' @param x Model object
 ##' @param value Vector of variables or formula specifying which nodes to
@@ -13,14 +13,14 @@
 ##' @keywords models regression
 ##' @export
 ##' @examples
-##' 
+##'
 ##' m <- lvm()
 ##' addvar(m) <- ~y1+y2+x
 ##' covariance(m) <- y1~y2
 ##' regression(m) <- c(y1,y2) ~ x
 ##' ### Cancel the covariance between the residuals of y1 and y2
 ##' cancel(m) <- y1~y2
-##' ### Remove y2 from the model 
+##' ### Remove y2 from the model
 ##' rmvar(m) <- ~y2
 ##'
 "kill" <- function(x, ...) UseMethod("kill")
@@ -49,7 +49,7 @@
   if (length(idx)>0) {
       x$attributes$parameter[idx] <- x$expar[idx] <- x$exfix[idx] <- NULL
       if (length(x$exfix)==0) {
-          x$exfix <- x$expar <- x$attributes$parameter <- NULL    
+          x$exfix <- x$expar <- x$attributes$parameter <- NULL
       }
       index(x) <- reindex(x)
   }
@@ -57,7 +57,7 @@
   if (length(idx)==0)
     return(x)
   vv <- vars(x)[idx]
-  keep <- setdiff(1:length(vars(x)),idx)
+  keep <- setdiff(seq_along(vars(x)),idx)
   x$M <- x$M[keep,keep,drop=FALSE]
   x$par <- x$par[keep,keep,drop=FALSE]
   x$fix <- x$fix[keep,keep,drop=FALSE]
@@ -65,7 +65,7 @@
   x$covfix <- x$covfix[keep,keep,drop=FALSE]
   x$cov <- x$cov[keep,keep,drop=FALSE]
   x$mean <- (x$mean)[-idx]
-  x$exogenous <- setdiff(exogenous(x),vv)  
+  x$exogenous <- setdiff(exogenous(x),vv)
   x$latent[vv] <- NULL
   index(x) <- reindex(x)
   return(x)
