@@ -15,15 +15,15 @@
 pdfconvert <- function(files, dpi=300, resolution=1024, gsopt, format="png", ...) {
   if (missing(gsopt))
     gsopt <- "-dSAFTER -dBATCH -dNOPAUSE -sDEVICE=png16m -dGraphicsAlphaBits=4 -dTextAlphaBits=4"
-  cmd1 <- paste("gs -r",dpi," -dBackgroundColor='16#ffffff'",sep="")
-  cmd2 <- paste("mogrify -resize ", resolution,sep="")
+  cmd1 <- paste0("gs -r",dpi," -dBackgroundColor='16#ffffff'")
+  cmd2 <- paste0("mogrify -resize ", resolution)
   for (f in files) {
     f0 <- strsplit(f,".pdf")[1]
     f.out <- paste(f0,format,sep=".")
     f.pdf <- paste(f0,"pdf",sep=".")
-    mycmd1 <- paste(cmd1, " ", gsopt, " -sOutputFile=", f.out, " > /dev/null ", f.pdf, sep="")
+    mycmd1 <- paste0(cmd1, " ", gsopt, " -sOutputFile=", f.out, " > /dev/null ", f.pdf)
     ##                   " && ", cmd2, " ", f.png, sep="")
-    mycmd2 <- paste(cmd2, " ", f.out, sep="")
+    mycmd2 <- paste0(cmd2, " ", f.out)
     cat(f.pdf)
     system(mycmd1)
     cat(" -> ")
